DmxMacro class abstract base

A user-defined macro: a name and a way to expand dartmacros.api.

Constructors

DmxMacro()
Const-constructible by subclasses.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The @dmx('name') this macro answers to.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

expand(DmxInvocation invocation) FutureOr<DmxOutput>
The generated members for one annotated declaration.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited